@@ -30,6 +30,28 @@ PipedApi::PipedApi(QNetworkAccessManager *netManager, QObject *parent)
 {
 }
 
+bool PipedApi::isLoggedIn() const
+{
+    return false;
+}
+
+bool PipedApi::canLogIn() const
+{
+    return false;
+}
+
+void PipedApi::loadCredentials(const QString &prefix)
+{
+}
+
+void PipedApi::saveCredentials(const QString &prefix)
+{
+}
+
+void PipedApi::wipeCredentials(const QString &prefix)
+{
+}
+
 bool PipedApi::supportsFeature(AbstractApi::SupportedFeature feature)
 {
     switch (feature) {
@@ -41,11 +63,11 @@ bool PipedApi::supportsFeature(AbstractApi::SupportedFeature feature)
     return false;
 }
 
-QFuture<LogInResult> PipedApi::logIn(QStringView username, QStringView password)
+QFuture<LogInResult> PipedApi::logIn(const QString &username, const QString &password)
 {
     QUrlQuery params;
-    params.addQueryItem(QStringLiteral("email"), QString::fromUtf8(QUrl::toPercentEncoding(username.toString())));
-    params.addQueryItem(QStringLiteral("password"), QString::fromUtf8(QUrl::toPercentEncoding(password.toString())));
+    params.addQueryItem(QStringLiteral("email"), QString::fromUtf8(QUrl::toPercentEncoding(username)));
+    params.addQueryItem(QStringLiteral("password"), QString::fromUtf8(QUrl::toPercentEncoding(password)));
     params.addQueryItem(QStringLiteral("action"), QStringLiteral("signin"));
 
     QUrl url = apiUrl(API_LOGIN);
@@ -59,36 +81,28 @@ QFuture<LogInResult> PipedApi::logIn(QStringView username, QStringView password)
     request.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::RedirectPolicy::ManualRedirectPolicy);
 
     return post<LogInResult>(std::move(request), params.toString().toUtf8(), [=](QNetworkReply *reply) -> LogInResult {
-        const auto cookies = reply->header(QNetworkRequest::SetCookieHeader).value<QList<QNetworkCookie>>();
-
-        if (!cookies.isEmpty()) {
-            m_credentials.setUsername(username);
-            m_credentials.setCookie(cookies.first());
-            Q_EMIT credentialsChanged();
-            return m_credentials;
-        }
         return std::pair(QNetworkReply::ContentAccessDenied, i18n("Username or password is wrong."));
     });
 }
 
-QFuture<VideoResult> PipedApi::requestVideo(QStringView videoId)
+QFuture<VideoResult> PipedApi::requestVideo(const QString &videoId)
 {
     return get<VideoResult>(QNetworkRequest(videoUrl(videoId)), [=](QNetworkReply *reply) -> VideoResult {
         if (auto doc = QJsonDocument::fromJson(reply->readAll()); !doc.isNull()) {
             auto video = Video::fromJson(doc);
-            video.setVideoId(videoId.toString()); // Piped doesn't give us the video id in the respone...
+            video.setVideoId(videoId); // Piped doesn't give us the video id in the respone...
             return video;
         }
         return invalidJsonError();
     });
 }
 
-QString PipedApi::resolveVideoUrl(QStringView videoId)
+QString PipedApi::resolveVideoUrl(const QString &videoId)
 {
     return QStringLiteral("ytdl://%1").arg(videoId);
 }
 
-QFuture<SearchListResult> PipedApi::requestSearchResults(const SearchParameters &parameters)
+QFuture<SearchListResult> PipedApi::requestSearchResults(const SearchParameters &parameters, Paginator *paginator)
 {
     auto url = videoListUrl(Search, QStringLiteral(""), parameters.toPipedQueryParameters());
     auto request = QNetworkRequest(url);
@@ -110,11 +124,8 @@ QFuture<SearchListResult> PipedApi::requestSearchResults(const SearchParameters
     });
 }
 
-QFuture<VideoListResult> PipedApi::requestFeed(qint32 page)
+QFuture<VideoListResult> PipedApi::requestFeed(Paginator *paginator)
 {
-    QHash<QString, QString> parameters;
-    parameters.insert(QStringLiteral("page"), QString::number(page));
-
     // TODO: piped stub
     return {};
 }
@@ -124,7 +135,7 @@ QFuture<VideoListResult> PipedApi::requestTop()
     return {};
 }
 
-QFuture<VideoListResult> PipedApi::requestTrending(TrendingTopic topic)
+QFuture<VideoListResult> PipedApi::requestTrending(TrendingTopic topic, Paginator *paginator)
 {
     QHash<QString, QString> parameters;
     switch (topic) {
@@ -146,10 +157,9 @@ QFuture<VideoListResult> PipedApi::requestTrending(TrendingTopic topic)
     return requestVideoList(Trending, QStringLiteral(""), parameters);
 }
 
-QFuture<VideoListResult> PipedApi::requestChannel(QStringView query, qint32 page)
+QFuture<VideoListResult> PipedApi::requestChannel(const QString &query, Paginator *paginator)
 {
-    Q_UNUSED(page)
-    return requestVideoList(Channel, query.toString(), {});
+    return requestVideoList(Channel, query, {});
 }
 
 QFuture<SubscriptionsResult> PipedApi::requestSubscriptions()
@@ -158,24 +168,23 @@ QFuture<SubscriptionsResult> PipedApi::requestSubscriptions()
     return {};
 }
 
-QFuture<Result> PipedApi::subscribeToChannel(QStringView channel)
+QFuture<Result> PipedApi::subscribeToChannel(const QString &channel)
 {
     // TODO: piped stub
     Q_UNUSED(channel)
     return {};
 }
 
-QFuture<Result> PipedApi::unsubscribeFromChannel(QStringView channel)
+QFuture<Result> PipedApi::unsubscribeFromChannel(const QString &channel)
 {
     // TODO: piped stub
     Q_UNUSED(channel)
     return {};
 }
 
-QFuture<HistoryResult> PipedApi::requestHistory(qint32 page)
+QFuture<HistoryResult> PipedApi::requestHistory(Paginator *paginator)
 {
     // TODO: piped stub
-    Q_UNUSED(page)
     return {};
 }
 
@@ -193,9 +202,9 @@ QFuture<Result> PipedApi::markUnwatched(const QString &videoId)
     return {};
 }
 
-QFuture<CommentsResult> PipedApi::requestComments(const QString &videoId, const QString &continuation)
+QFuture<CommentsResult> PipedApi::requestComments(const QString &videoId, Paginator *paginator)
 {
-    Q_UNUSED(continuation)
+    Q_UNUSED(paginator)
 
     if (videoId.isEmpty()) {
         qWarning() << "Not trying to load comments for an empty video id.";
@@ -214,7 +223,7 @@ QFuture<CommentsResult> PipedApi::requestComments(const QString &videoId, const
                 Comment::fromJson(val.toObject(), comment);
                 return comment;
             });
-            return Comments{comments, {}};
+            return comments;
         }
         return invalidJsonError();
     });
@@ -268,7 +277,7 @@ QFuture<VideoListResult> PipedApi::requestPlaylist(const QString &plid)
     });
 }
 
-QFuture<ChannelResult> PipedApi::requestChannelInfo(QStringView queryd)
+QFuture<ChannelResult> PipedApi::requestChannelInfo(const QString &queryd)
 {
     QUrl url = apiUrl(API_CHANNEL_INFO % u'/' % queryd);
 
@@ -282,6 +291,12 @@ QFuture<ChannelResult> PipedApi::requestChannelInfo(QStringView queryd)
     });
 }
 
+QFuture<PlaylistsResult> PipedApi::requestChannelPlaylists(const QString &channelId)
+{
+    // TODO: piped stub
+    return {};
+}
+
 QFuture<Result> PipedApi::addVideoToPlaylist(const QString &plid, const QString &videoId)
 {
     // TODO: piped stub
@@ -355,12 +370,6 @@ QFuture<VideoListResult> PipedApi::requestVideoList(VideoListType queryType, con
 QNetworkRequest PipedApi::authenticatedNetworkRequest(QUrl &&url)
 {
     QNetworkRequest request(url);
-    if (!m_credentials.isAnonymous()) {
-        const QList<QNetworkCookie> cookies{m_credentials.cookie().value()};
-        request.setHeader(QNetworkRequest::CookieHeader, QVariant::fromValue(cookies));
-    }
-    // some invidious instances redirect some calls using reverse proxies
-    request.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::NoLessSafeRedirectPolicy);
     return request;
 }
 
@@ -375,7 +384,7 @@ QUrlQuery PipedApi::genericUrlQuery() const
     return query;
 }
 
-QUrl PipedApi::videoUrl(QStringView videoId) const
+QUrl PipedApi::videoUrl(const QString &videoId) const
 {
     return apiUrl(API_VIDEOS % u'/' % videoId);
 }
